==> 0.0.2.tar.gz: lib/neo4dart.dart <==
library neo4dart;

import 'dart:convert';
import 'dart:async';

import 'package:http/http.dart' as http;

import 'package:logging/logging.dart';
import 'package:quiver/core.dart';
import 'package:quiver/collection.dart';
import 'package:collection/equality.dart';

import 'dart:mirrors';

part 'src/neo4dart/model/annotations/direction.dart';
part 'src/neo4dart/model/annotations/relationship.dart';
part 'src/neo4dart/model/annotations/relationship_via.dart';
part 'src/neo4dart/model/annotations/start_node.dart';
part 'src/neo4dart/model/annotations/end_node.dart';

part 'src/neo4dart/client/neo_client.dart';

part 'src/neo4dart/client/get/neo_client_get.dart';

part 'src/neo4dart/client/batch/batch_executor.dart';
part 'src/neo4dart/client/batch/batch_interpreter.dart';
part 'src/neo4dart/client/batch/entity/batch_token.dart';
part 'src/neo4dart/client/batch/entity/relationship_with_nodes.dart';
part 'src/neo4dart/client/batch/insert/batch_insert_builder.dart';
part 'src/neo4dart/client/batch/insert/batch_insert_executor.dart';
part 'src/neo4dart/client/batch/find/batch_find_executor.dart';
part 'src/neo4dart/client/batch/find/batch_find_builder.dart';
part 'src/neo4dart/client/batch/update/batch_update_builder.dart';
part 'src/neo4dart/client/batch/update/batch_update_executor.dart';

part 'src/neo4dart/client/cypher/cypher_executor.dart';
part 'src/neo4dart/client/cypher/find/cypher_find_builder.dart';
part 'src/neo4dart/client/cypher/find/cypher_find_executor.dart';
part 'src/neo4dart/client/cypher/find/cypher_find_interpreter.dart';
part 'src/neo4dart/client/cypher/entity/cypher_response.dart';
part 'src/neo4dart/client/cypher/delete/cypher_delete_builder.dart';
part 'src/neo4dart/client/cypher/delete/cypher_delete_executor.dart';

part 'src/neo4dart/service/insert/neo_service_insert.dart';
part 'src/neo4dart/service/find/neo_service_find.dart';
part 'src/neo4dart/service/update/neo_service_update.dart';
part 'src/neo4dart/service/delete/neo_service_delete.dart';

part 'src/neo4dart/model/node.dart';
part 'src/neo4dart/model/relation.dart';
part 'src/neo4dart/model/neo_entity.dart';
part 'src/neo4dart/model/neo_type.dart';
part 'src/neo4dart/model/response_entity.dart';
part 'src/neo4dart/model/response/neo_response.dart';
part 'src/neo4dart/model/response/label_response.dart';
part 'src/neo4dart/model/response/node_response.dart';
part 'src/neo4dart/model/response/relation_response.dart';
part 'src/neo4dart/model/response/around_node_response.dart';
part 'src/neo4dart/model/response/response_converter.dart';

part 'src/neo4dart/util/reflection_util.dart';

==> 0.0.5.tar.gz: lib/neo4dart.dart <==
library neo4dart;

import 'dart:convert';

import 'package:http/http.dart' as http;

import 'package:logging/logging.dart';
import 'package:quiver/core.dart';
import 'package:quiver/collection.dart';
import 'package:collection/equality.dart';

import 'dart:mirrors';

part 'src/neo4dart/model/annotations/direction.dart';
part 'src/neo4dart/model/annotations/relationship.dart';
part 'src/neo4dart/model/annotations/relationship_via.dart';
part 'src/neo4dart/model/annotations/start_node.dart';
part 'src/neo4dart/model/annotations/end_node.dart';
part 'src/neo4dart/model/annotations/data.dart';
part 'src/neo4dart/model/annotations/node.dart';
part 'src/neo4dart/model/annotations/relation.dart';

part 'src/neo4dart/client/neo_client.dart';

part 'src/neo4dart/client/get/neo_client_get.dart';

part 'src/neo4dart/client/batch/batch_executor.dart';
part 'src/neo4dart/client/batch/batch_interpreter.dart';
part 'src/neo4dart/client/batch/entity/batch_token.dart';
part 'src/neo4dart/client/batch/entity/relationship_with_nodes.dart';
part 'src/neo4dart/client/batch/insert/batch_insert_builder.dart';
part 'src/neo4dart/client/batch/insert/batch_insert_executor.dart';
part 'src/neo4dart/client/batch/find/batch_find_executor.dart';
part 'src/neo4dart/client/batch/find/batch_find_builder.dart';
part 'src/neo4dart/client/batch/update/batch_update_builder.dart';
part 'src/neo4dart/client/batch/update/batch_update_executor.dart';

part 'src/neo4dart/client/cypher/cypher_executor.dart';
part 'src/neo4dart/client/cypher/find/cypher_find_builder.dart';
part 'src/neo4dart/client/cypher/find/cypher_find_executor.dart';
part 'src/neo4dart/client/cypher/find/cypher_find_interpreter.dart';
part 'src/neo4dart/client/cypher/entity/cypher_response.dart';
part 'src/neo4dart/client/cypher/delete/cypher_delete_builder.dart';
part 'src/neo4dart/client/cypher/delete/cypher_delete_executor.dart';

part 'src/neo4dart/service/insert/neo_service_insert.dart';
part 'src/neo4dart/service/find/neo_service_find.dart';
part 'src/neo4dart/service/update/neo_service_update.dart';
part 'src/neo4dart/service/delete/neo_service_delete.dart';

part 'src/neo4dart/model/neo_type.dart';
part 'src/neo4dart/model/response_entity.dart';
part 'src/neo4dart/model/response/neo_response.dart';
part 'src/neo4dart/model/response/label_response.dart';
part 'src/neo4dart/model/response/node_response.dart';
part 'src/neo4dart/model/response/relation_response.dart';
part 'src/neo4dart/model/response/around_node_response.dart';
part 'src/neo4dart/model/response/response_converter.dart';

part 'src/neo4dart/util/reflection_util.dart';
